pub enum Register {
Show 26 variants
MagicValue = 0,
Version = 4,
DeviceId = 8,
VendorId = 12,
DeviceFeatures = 16,
DeviceFeaturesSel = 20,
DriverFeatures = 32,
DriverFeaturesSel = 36,
GuestPageSize = 40,
QueueSel = 48,
QueueNumMax = 52,
QueueNum = 56,
QueueAlign = 60,
QueuePfn = 64,
QueueReady = 68,
QueueNotify = 80,
InterruptStatus = 96,
InterruptAck = 100,
Status = 112,
QueueDescLow = 128,
QueueDescHigh = 132,
DriverDescLow = 144,
DriverDescHigh = 148,
DeviceDescLow = 160,
DeviceDescHigh = 164,
DeviceConfig = 256,
}Expand description
Register enum for Virtio devices
This enum represents the registers of the Virtio device. Each variant corresponds to a specific register offset. The offsets are defined in the Virtio specification. The register offsets are used to access the device’s configuration and status.
Variants
MagicValue = 0
Version = 4
DeviceId = 8
VendorId = 12
DeviceFeatures = 16
DeviceFeaturesSel = 20
DriverFeatures = 32
DriverFeaturesSel = 36
GuestPageSize = 40
QueueSel = 48
QueueNumMax = 52
QueueNum = 56
QueueAlign = 60
QueuePfn = 64
QueueReady = 68
QueueNotify = 80
InterruptStatus = 96
InterruptAck = 100
Status = 112
QueueDescLow = 128
QueueDescHigh = 132
DriverDescLow = 144
DriverDescHigh = 148
DeviceDescLow = 160
DeviceDescHigh = 164
DeviceConfig = 256
Implementations